pub struct DetResult {}Expand description
Result from building a single <det> element.
Fields
xml: StringThe serialised <det> XML string.
icms_totals: IcmsTotalsAccumulated ICMS totals contributed by this item.
v_ipi: i64IPI value in cents contributed by this item.
v_pis: i64PIS value in cents contributed by this item.
v_cofins: i64COFINS value in cents contributed by this item.
v_ii: i64II (import tax) value in cents contributed by this item.
v_frete: i64Freight value in cents for this item.
v_seg: i64Insurance value in cents for this item.
v_desc: i64Discount value in cents for this item.
v_outro: i64Other expenses value in cents for this item.
ind_tot: u8Whether this item counts towards the invoice total (indTot).
v_tot_trib: i64Approximate total tax for this item (vTotTrib). Optional.
v_ipi_devol: i64IPI devolution value in cents contributed by this item.
has_issqn: boolWhether this item uses ISSQN instead of ICMS.